import * as React from 'react';
import * as ReactDOM from 'react-dom';

import {
  Dialog,
  Divider,
  FlatButton,
  MenuItem,
  Paper,
  RaisedButton,
  SelectField,
  Slider,
  TextField,
} from 'material-ui';

export interface Props {
  isSignin?: boolean;
  onSignin?: (signinId: string, signinPw: string) => void;
  onSignup?: () => void;
  onResetPassword?: () => void;
}

export interface State {
  signinId: string;
  signinPw: string;
}

export class Signin extends React.Component<Props, State> {
  public static defaultProps: Partial<Props> = {
    onSignin: (signinId: string, signinPw: string): void => {
      console.log('onSignin');
    },
    onSignup: (): void => {
      console.log('onSignup');
    },
    onResetPassword: (): void => {
      console.log('onResetPassword');
    },
  };

  public constructor(props: Props, context: State) {
    super(props, context);

    this.state = {
      signinId: '',
      signinPw: '',
    };
  }

  public render(): JSX.Element {

    return (this.props.isSignin ? <div>Signed</div> :
      <div>
        <TextField
          hintText='smith@gmail.com'
          floatingLabelText='Email address*'
          errorText=''
          underlineShow={true}
          value={this.state.signinId}
          onChange={(e, newValue) => this.setState({ signinId: newValue })}
        />
        <br />
        <TextField
          hintText='Password'
          floatingLabelText='Password'
          type='password'
          value={this.state.signinPw}
          onChange={(e, newValue) => this.setState({ signinPw: newValue })}
        />
        <br />

        <RaisedButton
          label='Sign In'
          primary={true}
          onClick={(e) => this.props.onSignin(this.state.signinId, this.state.signinPw)}
        />
        <RaisedButton
          label='Sign Up'
          primary={false}
          onClick={this.props.onSignup}
        />
        <RaisedButton
          label='Reset Password'
          primary={false}
          onClick={this.props.onResetPassword}
        />

      </div>
    );
  }
}

export default Signin;
