import { SagaIterator } from 'redux-saga';
import { call, Effect, fork, put, takeLatest } from 'redux-saga/effects';

import AppContext from '@overflow/commons/context';
import Action from '@overflow/commons/redux/Action';

import SensorItem from '../../api/model/SensorItem';
import SensorItemService from '../../api/service/SensorItemService';
import * as ItemReadAllBySensorActions from '../action/item_read_all_by_sensor';
import ItemReadAllBySensorActionsPayload from '../payload/ItemReadAllBySensorPayload';

function* readAllItemBySensor(action: Action<ItemReadAllBySensorActionsPayload>): SagaIterator {
  try {
    const {sensor} = action.payload;
    // yield put({
    //   type: types.SENDING_REQUEST,
    //   payload: {sendingRequest: true},
    // });

    const retSensor = yield call(AppContext.getService<SensorItemService>().readAllBySensor, sensor);

    // if (responseBody.token === undefined) {
    //   throw new Error(MESSAGES.UNABLE_TO_FIND_TOKEN_IN_LOGIN_RESPONSE);
    // }
    yield put(ItemReadAllBySensorActions.requestSuccess(retSensor));
  } catch (e) {
    yield put(ItemReadAllBySensorActions.requestFailure(e));
  } finally {
    // yield put({
    //   type: types.SENDING_REQUEST,
    //   payload: {sendingRequest: false},
    // });
  }
}

export function* watchReadAllItemBySensor(): SagaIterator {
  yield takeLatest(ItemReadAllBySensorActions.REQUEST, readAllItemBySensor);
}
